@@ -30,7 +30,8 @@ class P4Client(object):
         self.server = server
 
         if not self.__p4config_exists():
-            logging.warning("No .p4config file found in %s!" % self.perforce_root)
+            if not silent:
+                logging.warning("No .p4config file found in %s!" % self.perforce_root)
 
         if user is None:
             self.user = self.get_p4_setting("P4USER")
@@ -483,7 +484,7 @@ class P4Client(object):
             else:
                 all_files.extend([os.path.join(folder, file) for file in os.listdir(folder) if os.path.isfile(os.path.join(folder, file))])
 
-        self.add_or_edit_files(all_files, changelist=changelist)
+        return self.add_or_edit_files(all_files, changelist=changelist)
 
     def add_or_edit_files(self, file_list, changelist="default"):
         """
@@ -812,12 +813,20 @@ class P4Client(object):
             p4file.set_local_file_path(self.__get_dict_value(file_dict, "clientFile"))
             p4file.set_have_revision(self.__get_dict_value(file_dict, "haveRev"))
             p4file.set_head_revision(self.__get_dict_value(file_dict, "headRev"))
-            p4file.set_checked_out_by(self.__get_dict_value(file_dict, "otherOpen0"))
             p4file.set_last_submit_time(self.__get_dict_value(file_dict, "headTime"))
             p4file.set_action(self.__get_dict_value(file_dict, "action"))
             p4file.set_head_action(self.__get_dict_value(file_dict, "headAction"))
             p4file.set_raw_data(str(file_dict))
 
+            opened_by = []
+            for key, value in file_dict.items():
+                other_open = "otherOpen" if sys.version_info.major == 2 else "otherOpen".encode()
+                if other_open in key and key != other_open:
+                    value = self.__get_dict_value(file_dict, key)
+                    opened_by.append(value)
+
+            p4file.set_checked_out_by(opened_by)
+
             if allow_invalid_files:
                 p4files.append(p4file)
             else:
